"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NotifyBase = void 0;
const node_fetch_1 = __importDefault(require("node-fetch"));
const https_proxy_agent_1 = __importDefault(require("https-proxy-agent"));
class NotifyBase {
    constructor(config) {
        if (config.proxy) {
            this.proxyAgent = https_proxy_agent_1.default(config.proxy);
        }
    }
    /**
     * @param  {string} url
     * @param  {RequestInit} options
     * @returns Promise
     */
    async request(url, options) {
        const defaultOptions = {
            headers: { 'Content-Type': 'application/json' },
        };
        if (this.proxyAgent) {
            defaultOptions.agent = this.proxyAgent;
        }
        const mergedOptions = {
            ...defaultOptions,
            ...options,
        };
        if (options.body) {
            mergedOptions.body = JSON.stringify(options.body);
        }
        const response = await node_fetch_1.default(url, mergedOptions);
        const contentType = response.headers.get('content-type');
        if (!contentType)
            return null;
        if (contentType.indexOf('application/json') > -1) {
            return await response.json();
        }
        return await response.text();
    }
    /**
     * @param  {string} url
     * @param  {any} data
     * @returns Promise
     */
    async requestPost(url, data) {
        return await this.request(url, { method: 'post', body: data });
    }
    /**
     * @param  {string} url
     * @returns Promise
     */
    async requestGet(url) {
        return await this.request(url, { method: 'get' });
    }
}
exports.NotifyBase = NotifyBase;
