import { BaseConfig, NotifyBase, INotifyBase, INotifyResult } from './base';
export interface DingConfig extends BaseConfig {
    token: string;
    secret?: string;
}
export interface DingMessageAt {
    atMobiles?: Array<string>;
    isAtAll?: boolean;
}
export interface DingTextMessage {
    content: string;
}
export interface DingLinkMessage {
    text: string;
    title: string;
    picUrl: string;
    messageUrl: string;
}
export interface DingMarkdownMessage {
    title: string;
    text: string;
}
export interface DingActionCardMessage {
    title: string;
    text: string;
    btnOrientation?: '0' | '1';
    singleTitle: string;
    singleURL: string;
}
export interface DingActionsCardMessage {
    title: string;
    text: string;
    btnOrientation?: '0' | '1';
    hideAvatar: '0' | '1';
    btns: Array<{
        title: string;
        actionURL: string;
    }>;
}
export interface DingFeedCardLinksMessage {
    [index: number]: {
        title: string;
        messageURL: string;
        picURL: string;
    };
}
export interface DingMessage {
    msgtype: 'text' | 'link' | 'markdown' | 'actionCard' | 'feedCard';
    at?: DingMessageAt;
    text?: DingTextMessage;
    link?: DingLinkMessage;
    markdown?: DingMarkdownMessage;
    actionCard?: DingActionCardMessage | DingActionsCardMessage;
    feedCard?: {
        links: DingFeedCardLinksMessage;
    };
}
export declare class DingNotify extends NotifyBase implements INotifyBase {
    private token;
    private secret;
    constructor(config: DingConfig);
    /**
     * @param  {DingMessage} message
     * @returns Promise
     */
    send(message: DingMessage): Promise<INotifyResult>;
    /**
     * @param  {string|DingTextMessage} text
     * @returns Promise
     */
    sendText(text: string | DingTextMessage): Promise<INotifyResult>;
    /**
     * @param  {DingLinkMessage} link
     * @returns Promise
     */
    sendLink(link: DingLinkMessage): Promise<INotifyResult>;
    /**
     * @param  {DingMarkdownMessage} markdown
     * @returns Promise
     */
    sendMarkdown(markdown: DingMarkdownMessage): Promise<INotifyResult>;
    /**
     * @param  {DingActionCardMessage|DingActionsCardMessage} actionCard
     * @returns Promise
     */
    sendActionCard(actionCard: DingActionCardMessage | DingActionsCardMessage): Promise<INotifyResult>;
    /**
     * @param  {DingFeedCardLinksMessage} feedCardLinks
     * @returns Promise
     */
    sendFeedCard(feedCardLinks: DingFeedCardLinksMessage): Promise<INotifyResult>;
    /**
     * @param  {string} message
     * @param  {string} secret
     * @returns string
     */
    private genMessageSign;
}
