"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DingNotify = void 0;
const crypto_1 = __importDefault(require("crypto"));
const base_1 = require("./base");
class DingNotify extends base_1.NotifyBase {
    constructor(config) {
        super(config);
        this.token = '';
        this.secret = '';
        let { token, secret } = config;
        this.token = token;
        if (secret) {
            this.secret = secret;
        }
    }
    /**
     * @param  {DingMessage} message
     * @returns Promise
     */
    async send(message) {
        let apiUrl = `https://oapi.dingtalk.com/robot/send?access_token=${this.token}`;
        if (this.secret) {
            let timestamp = new Date().getTime().toString();
            let sign = encodeURIComponent(this.genMessageSign(`${timestamp}\n${this.secret}`, this.secret));
            apiUrl += `&timestamp=${timestamp}&sign=${sign}`;
        }
        const result = await this.requestPost(apiUrl, message);
        return {
            success: result.errcode === 0,
            data: result,
        };
    }
    /**
     * @param  {string|DingTextMessage} text
     * @returns Promise
     */
    async sendText(text) {
        let msg = {
            msgtype: 'text',
            text: { content: '' },
        };
        if (typeof text === 'string') {
            msg.text = { content: text };
        }
        else {
            msg.text = text;
        }
        return await this.send(msg);
    }
    /**
     * @param  {DingLinkMessage} link
     * @returns Promise
     */
    async sendLink(link) {
        let msg = {
            msgtype: 'link',
            link: link,
        };
        return await this.send(msg);
    }
    /**
     * @param  {DingMarkdownMessage} markdown
     * @returns Promise
     */
    async sendMarkdown(markdown) {
        let msg = {
            msgtype: 'markdown',
            markdown: markdown,
        };
        return await this.send(msg);
    }
    /**
     * @param  {DingActionCardMessage|DingActionsCardMessage} actionCard
     * @returns Promise
     */
    async sendActionCard(actionCard) {
        let msg = {
            msgtype: 'actionCard',
            actionCard: actionCard,
        };
        return await this.send(msg);
    }
    /**
     * @param  {DingFeedCardLinksMessage} feedCardLinks
     * @returns Promise
     */
    async sendFeedCard(feedCardLinks) {
        let msg = {
            msgtype: 'feedCard',
            feedCard: {
                links: feedCardLinks,
            },
        };
        return await this.send(msg);
    }
    /**
     * @param  {string} message
     * @param  {string} secret
     * @returns string
     */
    genMessageSign(message, secret) {
        return crypto_1.default.createHmac('SHA256', secret).update(message).digest('base64');
    }
}
exports.DingNotify = DingNotify;
