import { BaseConfig, NotifyBase, INotifyBase, INotifyResult } from './base';
export interface LarkConfig extends BaseConfig {
    token: string;
    secret?: string;
}
export interface LarkTextMessage {
    text: string;
}
export interface LarkImageMessage {
    image_key: string;
}
export interface LarkShareChatMessage {
    share_chat_id: string;
}
export interface LarkPostMessage {
    post: {
        [lang: string]: {
            title: string;
            content: Array<any>;
        };
    };
}
export interface LarkCardMessage {
    config?: {
        wide_screen_mode: boolean;
        enable_forward: boolean;
    };
    elements: Array<any>;
    header?: {
        title: any;
        template?: 'red' | 'blue' | 'wathet' | 'turquoise' | 'green' | 'yellow' | 'orange' | 'carmine' | 'violet' | 'purple' | 'indigo' | 'grey';
    };
}
export interface LarkMessage {
    timestamp?: string;
    sign?: string;
    msg_type: 'text' | 'post' | 'image' | 'share_chat' | 'interactive';
    content?: LarkTextMessage | LarkPostMessage | LarkShareChatMessage | LarkImageMessage;
    card?: LarkCardMessage;
}
export declare class LarkNotify extends NotifyBase implements INotifyBase {
    private apiUrl;
    private secret;
    constructor(config: LarkConfig);
    /**
     * @param  {LarkMessage} message
     * @returns Promise
     */
    send(message: LarkMessage): Promise<INotifyResult>;
    /**
     * @param  {string|LarkTextMessage} text
     * @returns Promise
     */
    sendText(text: string | LarkTextMessage): Promise<INotifyResult>;
    /**
     * @param  {string|LarkImageMessage} image_key
     * @returns Promise
     */
    sendImage(image_key: string | LarkImageMessage): Promise<INotifyResult>;
    /**
     * @param  {string|LarkShareChatMessage} share_chat_id
     * @returns Promise
     */
    sendShareChat(share_chat_id: string | LarkShareChatMessage): Promise<INotifyResult>;
    /**
     * @param  {LarkPostMessage} post
     * @returns Promise
     */
    sendPost(post: LarkPostMessage): Promise<INotifyResult>;
    /**
     * @param  {LarkCardMessage} card
     * @returns Promise
     */
    sendCard(card: LarkCardMessage): Promise<INotifyResult>;
    /**
     * @param  {string} message
     * @returns string
     */
    private genMessageSign;
}
