"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LarkNotify = void 0;
const crypto_1 = __importDefault(require("crypto"));
const base_1 = require("./base");
class LarkNotify extends base_1.NotifyBase {
    constructor(config) {
        super(config);
        this.apiUrl = '';
        this.secret = '';
        let { token, secret } = config;
        this.apiUrl = `https://open.feishu.cn/open-apis/bot/v2/hook/${token}`;
        if (secret) {
            this.secret = secret;
        }
    }
    /**
     * @param  {LarkMessage} message
     * @returns Promise
     */
    async send(message) {
        if (this.secret) {
            let timestamp = (new Date().getTime() / 1000).toFixed();
            let sign = this.genMessageSign(`${timestamp}\n${this.secret}`);
            message.timestamp = timestamp;
            message.sign = sign;
        }
        const result = await this.requestPost(this.apiUrl, message);
        return {
            success: result.StatusCode === 0,
            data: result,
        };
    }
    /**
     * @param  {string|LarkTextMessage} text
     * @returns Promise
     */
    async sendText(text) {
        let msg = {
            msg_type: 'text',
            content: { text: '' },
        };
        if (typeof text === 'string') {
            msg.content = { text };
        }
        else {
            msg.content = text;
        }
        return await this.send(msg);
    }
    /**
     * @param  {string|LarkImageMessage} image_key
     * @returns Promise
     */
    async sendImage(image_key) {
        let msg = {
            msg_type: 'image',
            content: {
                image_key: '',
            },
        };
        if (typeof image_key === 'string') {
            msg.content = { image_key };
        }
        else {
            msg.content = image_key;
        }
        return await this.send(msg);
    }
    /**
     * @param  {string|LarkShareChatMessage} share_chat_id
     * @returns Promise
     */
    async sendShareChat(share_chat_id) {
        let msg = {
            msg_type: 'share_chat',
            content: {
                share_chat_id: '',
            },
        };
        if (typeof share_chat_id === 'string') {
            msg.content = { share_chat_id };
        }
        else {
            msg.content = share_chat_id;
        }
        return await this.send(msg);
    }
    /**
     * @param  {LarkPostMessage} post
     * @returns Promise
     */
    async sendPost(post) {
        let msg = {
            msg_type: 'post',
            content: post,
        };
        return await this.send(msg);
    }
    /**
     * @param  {LarkCardMessage} card
     * @returns Promise
     */
    async sendCard(card) {
        let msg = {
            msg_type: 'interactive',
            card: card,
        };
        return await this.send(msg);
    }
    /**
     * @param  {string} message
     * @returns string
     */
    genMessageSign(message) {
        return crypto_1.default.createHmac('SHA256', message).update('').digest('base64');
    }
}
exports.LarkNotify = LarkNotify;
