import { BaseConfig, NotifyBase, INotifyBase, INotifyResult } from './base';
export interface WecomConfig extends BaseConfig {
    token: string;
}
export interface WecomTextMessage {
    content: string;
    mentioned_list?: Array<string>;
    mentioned_mobile_list?: Array<string>;
}
export interface WecomMarkdownMessage {
    content: string;
}
export interface WecomImageMessage {
    base64: string;
    md5: string;
}
export interface WecomNewsItemMessage {
    title: string;
    description: string;
    url: string;
    picurl: string;
}
export interface WecomNewsMessage {
    articles: Array<WecomNewsItemMessage>;
}
export interface WecomFileMessage {
    media_id: string;
}
export interface WecomMessage {
    msgtype: 'text' | 'markdown' | 'image' | 'news' | 'file';
    text?: WecomTextMessage;
    markdown?: WecomMarkdownMessage;
    image?: WecomImageMessage;
    news?: WecomNewsMessage;
    file?: WecomFileMessage;
}
export declare class WecomNotify extends NotifyBase implements INotifyBase {
    private apiUrl;
    /**
     * @param  {WecomConfig} config
     */
    constructor(config: WecomConfig);
    /**
     * @param  {WecomMessage} message
     * @returns Promise
     */
    send(message: WecomMessage): Promise<INotifyResult>;
    /**
     * @param  {string|WecomTextMessage} text
     * @returns Promise
     */
    sendText(text: string | WecomTextMessage): Promise<INotifyResult>;
    /**
     * @param  {string|WecomMarkdownMessage} markdown
     * @returns Promise
     */
    sendMarkdown(markdown: string | WecomMarkdownMessage): Promise<INotifyResult>;
}
