"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WecomNotify = void 0;
const base_1 = require("./base");
class WecomNotify extends base_1.NotifyBase {
    /**
     * @param  {WecomConfig} config
     */
    constructor(config) {
        super(config);
        this.apiUrl = '';
        this.apiUrl = `https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=${config.token}`;
    }
    /**
     * @param  {WecomMessage} message
     * @returns Promise
     */
    async send(message) {
        const result = await this.requestPost(this.apiUrl, message);
        return {
            success: result.errcode === 0,
            data: result,
        };
    }
    /**
     * @param  {string|WecomTextMessage} text
     * @returns Promise
     */
    async sendText(text) {
        let msg = {
            msgtype: 'text',
        };
        if (typeof text === 'string') {
            msg.text = {
                content: text,
            };
        }
        else {
            msg.text = text;
        }
        return await this.send(msg);
    }
    /**
     * @param  {string|WecomMarkdownMessage} markdown
     * @returns Promise
     */
    async sendMarkdown(markdown) {
        let msg = {
            msgtype: 'markdown',
        };
        if (typeof markdown === 'string') {
            msg.markdown = {
                content: markdown,
            };
        }
        else {
            msg.markdown = markdown;
        }
        return await this.send(msg);
    }
}
exports.WecomNotify = WecomNotify;
